@@ -1,8 +1,7 @@
 from lightbus.transports.redis.event import RedisEventTransport, StreamUse
 
-from kickredis.registry import ObjectRegistry
+from kickredis.registry import ObjectRegistry, Stream
 from kickredis.config import kicker_config
-from kickredis.shared import KStream
 
 
 class KickerRuntime:
@@ -20,8 +19,5 @@ class KickerRuntime:
     def event_transport(self):
         return self._event_transport
 
-    def get_kstream(self, stream_id):
-        return KStream(self.event_transport, stream_id)
-
 
 kicker_runtime = KickerRuntime()
